#ifndef _ARCLIBS_H
#define _ARCLIBS_H

/********************************************************/
/*
/*  Data Structures & Function prototypes for S.M.A.R.T
/*
/********************************************************/

#ifdef __cplusplus
extern "C" {
#endif


#define MAX_DATA_LENGTH             512
#define SHORT_SELF_TEST             1
#define EXTENDED_SELF_TEST          2


#ifdef _WIN32
class ARCLIB_API CArclibSMART : public CArclib
{
#else
class CArclibSMART : public CArclib 
{		
#endif
public:	

	// (O): Implemented
	// (X): Not Implemented
	enum SMART_CMD
	{
		R_SMART_DATA = 0,		// (O)Read smart data
		R_THLD_DATA,			// (O)Read threshold data
		ED_AUTOSAVE,			// (X)Enable/disable autosave
		S_ATTR,					// (X)Save attribute
		EXE_OFFLINE,			// (O)Execute offline
		R_LOG,					// (X)Read log
		W_LOG,					// (X)Write log
		RESERVED1,
		E_SMART,				// (O)Enable SMART
		D_SMART,				// (O)Disable SMART
		RET_SMART_STATUS,		// (X)Return SMART status
		ED_AUTO_OFFLINE,		// (X)Enable/Disable automatic offline
		RESERVED2,
		RESERVED3,
		RESERVED4,
		RESERVED5,
		RW_TEST,				// (O)Read/Write test
		STOP_RW_TEST,			// (O)Stop Read/Write test
		CHECK_RW_RESULT,		// (O)Check Read/Write Result
		RESERVED6
	};

	//################################################################################################
	// Function: ArcExeSMART
	// Parameters:  (i) cmd: the commands of above
	//				(i) drv: drive# where the SMART command is being executed
	//				(i) params: optional for EXE_OFFLINE, RW_TEST.
	//                          for EXE_OFFLINE: value SHORT_SELF_TEST indicates short self-test
	//				                             value EXTENDED_SELF_TEST indicates extended self-test
	//							for RW_TEST: percentage of RW_TEST
	//              (o) data: optional for R_SMART_DATA, R_THLD_DATA, CHECK_RW_RESULT 
	//						  the SMART data returned from the drive that indicates by drv, 
	//					      the memory allocation of 'data' is the responsibility of the
	//						  calling thread, and it's size should be >= 512 bytes					  
	//################################################################################################
	ARC_STATUS ArcExeSMART(int cmd, BYTE drv, BYTE params, PBYTE data);
};

#ifdef __cplusplus
}
#endif

#endif
